# Finite State Machine

## Develop

### Download project

    git clone https://gitlab.com/yuriylygin/state-machine.git
    python3.7 -m venv venv
    source venv/bin/activate
    pip install -e .[dev]

### Run tests 

    pytest -v